asr.setup.displacements
=======================

.. automodule:: asr.setup.displacements

   
   
   .. rubric:: Functions

   
   .. autofunction:: create_displacements_folder
   .. autofunction:: displace_atom
   .. autofunction:: get_all_displacements
   .. autofunction:: get_displacement_folder
   
   

   
   
   

   
   
   